@@ -2,6 +2,7 @@
 #define INIFILE_H
 
 #include <string>
+#include <boost/any.hpp>
 
 #define MAX_SECTIONxNAME_LEN 160
 #define MAX_KEYxNAME_LEN 160
@@ -48,6 +49,15 @@ public:
   bool SetSection(const char *_szSectionName);
   bool CreateSection(const char *_szSectionName);
 
+  /**
+   * Read a value from the configuration file
+   *
+   * @param key Key of value to read
+   * @param data variable to put value in
+   * @return True if value was found or false if default value was used
+   */
+  bool readVar(const std::string& key, boost::any& data);
+
   /**
    * Read a string value from the configuration file
    *
@@ -70,6 +80,14 @@ public:
   bool ReadNum(const std::string& key, char &data, char defValue = 0);
   bool ReadBool(const std::string& key, bool &data, const bool defValue = false);
 
+  /**
+   * Write a value to the configuration file
+   *
+   * @param key Key of value to write
+   * @param data Value to write
+   */
+  void writeVar(const std::string& key, const boost::any& data);
+
   /**
    * Write a string value to the configuration file
    *
