@@ -34,9 +34,10 @@ const unsigned short ICQ_SNACxFAM_LOCATION         = 0x0002;
 const unsigned short ICQ_SNACxFAM_BUDDY            = 0x0003;
 const unsigned short ICQ_SNACxFAM_MESSAGE          = 0x0004;
 const unsigned short ICQ_SNACxFAM_BOS              = 0x0009;
+const unsigned short ICQ_SNACxFAM_BART             = 0x0010;
 const unsigned short ICQ_SNACxFAM_LIST             = 0x0013;
 const unsigned short ICQ_SNACxFAM_VARIOUS          = 0x0015;
-const unsigned short ICQ_SNACxFAM_NEWUIN	   = 0x0017;
+const unsigned short ICQ_SNACxFAM_AUTH             = 0x0017;
 
 // Subtypes for service family
 const unsigned short ICQ_SNACxSUB_ERROR            = 0x0001; // server
@@ -99,11 +100,22 @@ const unsigned short ICQ_SNACxMETA                 = 0x0002; // client
 
 // Subtypes for new uin family
 const unsigned short ICQ_SNACxNEW_UIN_ERROR        = 0x0001; // server
+const unsigned short ICQ_SNACxAUTHxLOGON           = 0x0002; // client
+const unsigned short ICQ_SNACxAUTHxLOGON_REPLY     = 0x0003; // server
 const unsigned short ICQ_SNACxREGISTER_USER        = 0x0004; // client
 const unsigned short ICQ_SNACxNEW_UIN              = 0x0005; // server
+const unsigned short ICQ_SNACxAUTHxREQUEST_SALT    = 0x0006; // client
+const unsigned short ICQ_SNACxAUTHxSALT_REPLY      = 0x0007; // server
 const unsigned short ICQ_SNACxREQUEST_IMAGE        = 0x000C; // client
 const unsigned short ICQ_SNACxSEND_IMAGE           = 0x000D; // server
 
+// Subtypes for BART family
+const unsigned short ICQ_SNACxBART_ERROR           = 0x0001; // server
+const unsigned short ICQ_SNACxBART_UPLOAD          = 0x0002; // client
+const unsigned short ICQ_SNACxBART_UPLOADxACK      = 0x0003; // server
+const unsigned short ICQ_SNACxBART_DOWNLOADxREQUEST= 0x0006; // client
+const unsigned short ICQ_SNACxBART_DOWNLOADxREPLY  = 0x0007; // server
+
 // Subtypes for list family
 const unsigned short ICQ_SNACxLIST_REQUESTxRIGHTS  = 0x0002; // client
 const unsigned short ICQ_SNACxLIST_RIGHTSxGRANTED  = 0x0003; // server
@@ -116,12 +128,12 @@ const unsigned short ICQ_SNACxLIST_ROSTxUPD_GROUP  = 0x0009; // client
 const unsigned short ICQ_SNACxLIST_ROSTxREM        = 0x000A; // client
 const unsigned short ICQ_SNACxLIST_UPDxACK         = 0x000E; // server
 const unsigned short ICQ_SNACxLIST_ROSTxSYNCED     = 0x000F; // server
-const unsigned short ICQ_SNACxLIST_ROSTxEDITxSTART = 0x0011; // client
-const unsigned short ICQ_SNACxLIST_ROSTxEDITxEND   = 0x0012; // client
+const unsigned short ICQ_SNACxLIST_ROSTxEDITxSTART = 0x0011; // client, server
+const unsigned short ICQ_SNACxLIST_ROSTxEDITxEND   = 0x0012; // client, server
 const unsigned short ICQ_SNACxLIST_AUTHxREQ2       = 0x0014; // client
 const unsigned short ICQ_SNACxLIST_AUTHxREQ        = 0x0018; // client
 const unsigned short ICQ_SNACxLIST_AUTHxREQxSRV    = 0x0019; // server
-const unsigned short ICQ_SNACxLIST_AUTHxREPLY      = 0x001A; // client
+const unsigned short ICQ_SNACxLIST_AUTHxGRANT      = 0x001A; // client
 const unsigned short ICQ_SNACxLIST_AUTHxRESPONS    = 0x001B; // server
 const unsigned short ICQ_SNACxLIST_AUTHxADDED      = 0x001C; // server
 
@@ -267,42 +279,42 @@ const unsigned short ICQ_CMDxWPxWEB_PRESENCE    = 0x0C03;
 const unsigned short ICQ_CMDxWPxHOMEPAGE        = 0x1302;
 const unsigned short ICQ_CMDxWPxTIMEZONE        = 0x1603;
 const unsigned short ICQ_CMDxWPxBIRTHDAY        = 0x3A02;
-const unsigned short ICQ_CMDxWPxFNAME		= 0x4001;
-const unsigned short ICQ_CMDxWPxLNAME		= 0x4A01;
+const unsigned short ICQ_CMDxWPxFNAME           = 0x4001;
+const unsigned short ICQ_CMDxWPxLNAME           = 0x4A01;
 const unsigned short ICQ_CMDxWPxRECV_ICQ_SPAM   = 0x4803;
-const unsigned short ICQ_CMDxWPxALIAS		= 0x5401;
+const unsigned short ICQ_CMDxWPxALIAS           = 0x5401;
 const unsigned short ICQ_CMDxWPxABOUT           = 0x5802;
-const unsigned short ICQ_CMDxWPxEMAIL		= 0x5E01;
+const unsigned short ICQ_CMDxWPxEMAIL           = 0x5E01;
 const unsigned short ICQ_CMDxWPxHOME_ADDR       = 0x6201;
-const unsigned short ICQ_CMDxWPxAGE		= 0x6801;
+const unsigned short ICQ_CMDxWPxAGE             = 0x6801;
 const unsigned short ICQ_CMDxWPxHOME_ZIP        = 0x6D02;
 const unsigned short ICQ_CMDxWPxAGE2            = 0x7201;
 const unsigned short ICQ_CMDxWPxPHONExHOME      = 0x7602;
-const unsigned short ICQ_CMDxWPxGENDER		= 0x7C01;
+const unsigned short ICQ_CMDxWPxGENDER          = 0x7C01;
 const unsigned short ICQ_CMDxWPxHOME_FAX        = 0x8002;
-const unsigned short ICQ_CMDxWPxLANGUAGE	= 0x8601;
+const unsigned short ICQ_CMDxWPxLANGUAGE        = 0x8601;
 const unsigned short ICQ_CMDxWPxPHONExCELL      = 0x8A02;
-const unsigned short ICQ_CMDxWPxCITY		= 0x9001;
+const unsigned short ICQ_CMDxWPxCITY            = 0x9001;
 const unsigned short ICQ_CMDxWPxWORK_ADDR       = 0x9402;
-const unsigned short ICQ_CMDxWPxSTATE		= 0x9A01;
+const unsigned short ICQ_CMDxWPxSTATE           = 0x9A01;
 const unsigned short ICQ_CMDxWPxWORK_CITY       = 0x9E02;
-const unsigned short ICQ_CMDxWPxCOUNTRY		= 0xA401;
+const unsigned short ICQ_CMDxWPxCOUNTRY         = 0xA401;
 const unsigned short ICQ_CMDxWPxWORK_STATE      = 0xA802;
-const unsigned short ICQ_CMDxWPxCOMPANY		= 0xAE01;
+const unsigned short ICQ_CMDxWPxCOMPANY         = 0xAE01;
 const unsigned short ICQ_CMDxWPxWORK_COUNTRY    = 0xB202;
-const unsigned short ICQ_CMDxWPxCODEPT		= 0xB801;
+const unsigned short ICQ_CMDxWPxCODEPT          = 0xB801;
 const unsigned short ICQ_CMDxWPxWORK_ZIP        = 0xBD02;
-const unsigned short ICQ_CMDxWPxCOPOS		= 0xC201;
+const unsigned short ICQ_CMDxWPxCOPOS           = 0xC201;
 const unsigned short ICQ_CMDxWPxWORK_PHONE      = 0xC602;
-const unsigned short ICQ_CMDxWPxOCCUP		= 0xCC01;
+const unsigned short ICQ_CMDxWPxOCCUP           = 0xCC01;
 const unsigned short ICQ_CMDxWPxWORK_FAX        = 0xD002;
 const unsigned short ICQ_CMDxWPxWORK_URL        = 0xDA02;
-const unsigned short ICQ_CMDxWPxPASTAFF		= 0xD601;
-const unsigned short ICQ_CMDxWPxORGANIZ		= 0xFE01;
-const unsigned short ICQ_CMDxWPxINTEREST	= 0xEA01;
+const unsigned short ICQ_CMDxWPxPASTAFF         = 0xD601;
+const unsigned short ICQ_CMDxWPxORGANIZ         = 0xFE01;
+const unsigned short ICQ_CMDxWPxINTEREST        = 0xEA01;
 const unsigned short ICQ_CMDxWPxAUTH            = 0xF802;
-const unsigned short ICQ_CMDxWPxKEYWORD		= 0x2602;
-const unsigned short ICQ_CMDxWPxONLINE		= 0x3002;
+const unsigned short ICQ_CMDxWPxKEYWORD         = 0x2602;
+const unsigned short ICQ_CMDxWPxONLINE          = 0x3002;
 
 
 const unsigned short META_SUCCESS = 0x0A;
@@ -363,7 +375,7 @@ const unsigned short ICQ_CMDxSUB_SECURExOPEN       = 0x00EF;  // Licq extension
 
 
 // Special UINs
-const unsigned short ICQ_UINxPAGER		   = 0x000A;
+const unsigned short ICQ_UINxPAGER              = 0x000A;
 const unsigned short ICQ_UINxSMS                   = 0x03EA;
 
 // Status constants
@@ -468,6 +480,11 @@ const unsigned short CHARSET_ASCII   = 0x0000;
 const unsigned short CHARSET_UNICODE = 0x0002;
 const unsigned short CHARSET_CUSTOM  = 0x0003;
 
+// BART Types
+const unsigned short BART_TYPExBUDDY_ICON_SMALL = 0x0000;
+const unsigned short BART_TYPExBUDDY_ICON       = 0x0001;
+const unsigned short BART_TYPExSTATUS_STR       = 0x0002;
+
 //actual plugins
 const char PLUGIN_PHONExBOOK[]        = { 0x90, 0x7C, 0x21, 0x2C, 0x91, 0x4D,
                                           0xD3, 0x11, 0xAD, 0xEB, 0x00, 0x04,
@@ -544,6 +561,10 @@ const char ICQ_CAPABILITY_XTRAZ[]     = { 0x1A, 0x09, 0x3C, 0x6C, 0xD7, 0xFD,
                                           0x4E, 0xC5, 0x9D, 0x51, 0xA6, 0x47,
                                           0x4E, 0x34, 0xF5, 0xA0 };
 
+const char ICQ_CAPABILITY_BART[]      = { 0x09, 0x46, 0x13, 0x46, 0x4C, 0x7F,
+                                          0x11, 0xD1, 0x82, 0x22, 0x44, 0x45,
+                                          0x53, 0x54, 0x00, 0x00 };
+
 const char ICQ_CAPABILITY_LICQxVER[]  = { 'L',  'i',  'c',  'q',  ' ',  'c',
                                           'l',  'i',  'e',  'n',  't',  ' ',
                                           0x00, 0x00, 0x00, 0x00 };
