@@ -1259,6 +1259,17 @@ public:
   bool addUser(const UserId& userId, bool permanent = true,
       bool addToServer = true, unsigned short groupId = 0);
 
+  /**
+   * Add a temporary user to the list
+   * Will change the user to permanent and optionally add to server side list
+   *
+   * @param userId User to add
+   * @param addToServer True if server should be notified
+   * @param groupId Initial group to place user in or zero for no group
+   * @return True if user exists and was temporary, otherwise false
+   */
+  bool makeUserPermanent(const UserId& userId, bool addToServer = true, int groupId = 0);
+
   /**
    * Remove a user from the list
    *
