@@ -1,6 +1,7 @@
 #include "console.h"
 
 #include <cctype>
+#include <cstring>
 #include <string>
 
 #include "event_data.h"
@@ -420,7 +421,17 @@ void CLicqConsole::MenuGroup(char *_szArg)
 //TODO: fix this for other protocols
 void CLicqConsole::MenuAdd(char *szArg)
 {
-  if (szArg == NULL)
+  char* accountId = NULL;
+  char* param = NULL;
+
+  if (szArg != NULL)
+  {
+    char* tokptr;
+    accountId = strtok_r(szArg, " ", &tokptr);
+    param = strtok_r(NULL, " ", &tokptr);
+ }
+
+  if (accountId == NULL)
   {
     winMain->wprintf("%CSpecify a UIN to add.\n", COLOR_RED);
     return;
@@ -428,17 +439,12 @@ void CLicqConsole::MenuAdd(char *szArg)
 
   // Try to change groups
   bool bAlert = false;
+  if (param != NULL && strcasecmp(param, "alert") == 0)
+    bAlert = true;
 
-  while (*szArg != '\0' && *szArg != ' ') szArg++;
-  if (*szArg == ' ')
-  {
-    while (*szArg == ' ') szArg++;
-    if (strcasecmp(szArg, "alert") == 0)
-      bAlert = true;
-  }
   UserId userId = LicqUser::makeUserId(szArg, LICQ_PPID);
 
-  if (gUserManager.addUser(userId) == 0)
+  if (!gUserManager.addUser(userId))
   {
     winMain->wprintf("%CAdding user %s failed (duplicate user or invalid uin).\n",
         COLOR_RED, USERID_TOSTR(userId));
