@@ -1,14 +1,15 @@
 #ifndef EVENT_DATA_H
 #define EVENT_DATA_H
 
+#include <licq_types.h>
+
 // Data structures for input routines
 class CData
 {
 public:
-  CData (const char *i, unsigned long n)
-    { szId = i; nPPID = n, nPos = 0; szQuery[0] = '\0'; }
-  const char *szId;
-  unsigned long nPPID;
+  CData(const UserId& id)
+  { userId = id; nPos = 0; szQuery[0] = '\0'; }
+  UserId userId;
   unsigned short nPos;
   char szQuery[80];
 };
@@ -17,7 +18,7 @@ public:
 class DataMsg : public CData
 {
 public:
-  DataMsg(const char *i, unsigned long n) : CData(i, n)
+  DataMsg(const UserId& id) : CData(id)
     { szMsg[0] = '\0'; bUrgent = false; bServer = false; }
   char szMsg[1024];
   bool bUrgent;
@@ -28,7 +29,7 @@ public:
 class DataSendFile : public CData
 {
 public:
-  DataSendFile(const char *i, unsigned long n) : CData(i, n)
+  DataSendFile(const UserId& id) : CData(id)
     { szFileName[0] = '\0'; szDescription[0] = '\0'; bUrgent = false; }
   char szFileName[512];
   char szDescription[512];
@@ -39,7 +40,7 @@ public:
 class DataAutoResponse : public CData
 {
 public:
-  DataAutoResponse() : CData(NULL, 0)
+  DataAutoResponse() : CData(USERID_NONE)
     { szRsp[0] = '\0'; }
   char szRsp[1024];
 };
@@ -48,7 +49,7 @@ public:
 class DataUrl : public CData
 {
 public:
-  DataUrl(const char *i, unsigned long n) : CData(i, n)
+  DataUrl(const UserId& id) : CData(id)
     { szUrl[0] = '\0'; szDesc[0] = '\0'; bUrgent = false; bServer = false; }
   char szUrl[1024];
   char szDesc[1024];
@@ -59,14 +60,14 @@ public:
 class DataSms : public CData
 {
 public:
-  DataSms(const char *i, unsigned long n) : CData(i, n)
+  DataSms(const UserId& id) : CData(id)
     { szMsg[0] = '\0'; }
   char szMsg[1024];
 };
 class DataRegWizard : public CData
 {
 public:
-  DataRegWizard(const char *i = NULL, unsigned long n = 0) : CData(i, n)
+  DataRegWizard(const UserId& id = USERID_NONE) : CData(id)
     {  szOption[0] = '\0'; szPassword1[0] = '\0'; szPassword2[0] = '\0'; szUin[0] = '\0'; nState = 0; }
   char szOption[80];
   char szPassword1[80];
@@ -78,7 +79,7 @@ public:
 class DataUserSelect : public CData
 {
 public:
-  DataUserSelect(const char *i, unsigned long n) : CData(i, n)
+  DataUserSelect(const UserId& id) : CData(id)
     {  szPassword[0] = '\0'; }
   char szPassword[80];
 };
@@ -86,11 +87,12 @@ public:
 class DataSearch : public CData
 {
 public:
-  DataSearch() : CData(NULL, 0)
+  DataSearch() : CData(USERID_NONE)
       {  szAlias[0] = szFirstName[0] = szLastName[0] = szEmail[0] =
          szCity[0] = szState[0] = szCoName[0] = szCoDept[0] = szCoPos[0] = '\0';
          nState = nMinAge = nMaxAge = nGender = nLanguage = nCountryCode = 0;
-         bOnlineOnly = false; }
+         bOnlineOnly = false; szId = NULL; }
+  const char* szId;
   char szAlias[80];
   char szFirstName[80];
   char szLastName[80];
@@ -114,10 +116,10 @@ public:
 class DataFileChatOffer : public CData
 {
 public:
-  DataFileChatOffer(unsigned long _nSeq, const char *i, unsigned long n) : CData(i, n)
-    { szReason[0] = '\0'; nSequence = _nSeq; }
+  DataFileChatOffer(CEventFile *_f, const UserId& id) : CData(id)
+    { szReason[0] = '\0'; f = _f; }
+  CEventFile *f;
   char szReason[256];
-  unsigned long nSequence;
 };
 
 
