@@ -7,6 +7,8 @@ extern "C" {
 #include <cdk.h>
 }
 
+#include <licq_types.h>
+
 #undef COLOR_GREEN
 #define COLOR_GREEN 24
 #undef COLOR_RED
@@ -35,12 +37,6 @@ enum InputState { STATE_COMMAND, STATE_PENDING, STATE_MLE, STATE_LE, STATE_QUERY
 class CLicqConsole;
 class CData;
 
-struct SContact
-{
-  std::string szId;
-  unsigned long nPPID;
-};
-
 
 class CWindow
 {
@@ -69,8 +65,7 @@ public:
   unsigned long event;
   InputState state;
   CData *data;
-  std::string myLastId;
-  struct SContact sLastContact;
+  UserId sLastContact;
   unsigned short nLastHistory;
 protected:
   WINDOW *win;
