@@ -41,13 +41,13 @@ static const char OSD_CONF[] =
 "Wait=1\n"
 "\n"
 "# show logon/off of users ?\n"
-"# 0=dont show\n"
+"# 0=don't show\n"
 "# 1=show all\n"
 "# 2=show logon/off of Online notify users\n"
 "Showlogon=0\n"
 "\n"
 "# show messages of users ?\n"
-"# 0=dont show\n"
+"# 0=don't show\n"
 "# 1=show all\n"
 "# 2=show messages of Online notify users\n"
 "# 3=show only information that a message has been sent (like in sim)\n"
@@ -57,7 +57,7 @@ static const char OSD_CONF[] =
 "# how long after our logon or logoff should no message be displayed\n"
 "# this is some sort of a hack:\n"
 "# when we logon we get all the users who are online at the moment\n"
-"# as an logon event. Usually you dont want to show all of them in a row\n"
+"# as an logon event. Usually you don't want to show all of them in a row\n"
 "# (especially when wait = true), but only the ones who log on / off while\n"
 "# you are online.\n"
 "# note that this timeout is used when the plugin is loaded AFTER logon\n"
@@ -96,7 +96,7 @@ static const char OSD_CONF[] =
 "DelayPerCharacter=100\n"
 "\n"
 "# show an osd message whenever a user checks your auto response\n"
-"# 0=dont show\n"
+"# 0=don't show\n"
 "# 1=show all\n"
 "# 2=only for Online notify users\n"
 "ShowAutoResponseCheck=0\n"
