@@ -179,7 +179,7 @@ QString LicqKIMIface::displayName(const QString& uid)
 /*        kdDebug() << pUser->GetAlias()
                     << ": Licq ID=(" << pUser->PPID() << ", " << id << ")"
                     << "KABC ID=" << kabcID << endl;*/
-        QTextCodec* codec = UserCodec::codecForICQUser(pUser);
+    const QTextCodec* codec = UserCodec::codecForUser(pUser);
         QByteArray rawName = pUser->GetAlias();
         name = codec->toUnicode(rawName);
         FOR_EACH_PROTO_USER_BREAK
@@ -404,8 +404,10 @@ void LicqKIMIface::messageNewContact(const QString& contactId, const QString& pr
     unsigned long PPID = idForProtocol(protocol);
     if (PPID == 0) return;
 
+  UserId userId = LicqUser::makeUserId(contactId.toLatin1().data(), PPID);
+
     // check if user exists
-    const ICQUser* pUser = gUserManager.FetchUser(contactId.latin1(), PPID, LOCK_R);
+  const LicqUser* pUser = gUserManager.fetchUser(userId);
     if (pUser != 0)
     {
         gUserManager.DropUser(pUser);
@@ -487,15 +489,17 @@ bool LicqKIMIface::addContact(const QString& contactId,
     unsigned long PPID = idForProtocol(protocol);
     if (PPID == 0) return false;
 
+  UserId userId = LicqUser::makeUserId(contactId.toLatin1().data(), PPID);
+
     // check if user already exists
-    const ICQUser* pUser = gUserManager.FetchUser(contactId.latin1(), PPID, LOCK_R);
+  const LicqUser* pUser = gUserManager.fetchUser(userId);
     if (pUser != 0)
     {
         gUserManager.DropUser(pUser);
         return false;
     }
 
-    emit addUser(contactId.latin1(), PPID);
+  emit addUser(userId);
 
     // assume the user was added
     return true;
