@@ -154,6 +154,7 @@ UserMenu::UserMenu(QWidget* parent)
   myCustomArAction = addAction(tr("Custom Auto Response..."), this, SLOT(customAutoResponse()));
   myCustomArAction->setCheckable(true);
   addSeparator();
+  myMakePermanentAction = addAction(tr("Add to List"), this, SLOT(makePermanent()));
   myToggleFloatyAction = addAction(tr("Toggle &Floaty"), this, SLOT(toggleFloaty()));
   addMenu(myGroupsMenu);
   myRemoveUserAction = addAction(tr("Remove From List"), this, SLOT(removeContact()));
@@ -229,6 +230,7 @@ void UserMenu::aboutToShowMenu()
   int status = (u == NULL ? ICQ_STATUS_OFFLINE : u->Status());
 
   myCheckArAction->setEnabled(status != ICQ_STATUS_OFFLINE);
+  myMakePermanentAction->setVisible(u == NULL ? false : u->NotInList());
 
   if (status == ICQ_STATUS_OFFLINE || status == ICQ_STATUS_ONLINE)
     myCheckArAction->setText(tr("Check Auto Response"));
@@ -382,6 +384,11 @@ void UserMenu::customAutoResponse()
   new CustomAutoRespDlg(myUserId);
 }
 
+void UserMenu::makePermanent()
+{
+  gUserManager.makeUserPermanent(myUserId);
+}
+
 void UserMenu::toggleFloaty()
 {
   LicqGui::instance()->toggleFloaty(myUserId);
@@ -570,7 +577,7 @@ void UserMenu::toggleSystemGroup(QAction* action)
 {
   int gid = action->data().toInt();
 
-  if (gid == GROUP_IGNORE_LIST && !action->isChecked())
+  if (gid == GROUP_IGNORE_LIST && action->isChecked())
   {
     const LicqUser* u = gUserManager.fetchUser(myUserId, LOCK_R);
     if (u == NULL)
