@@ -1,7 +1,7 @@
 // -*- c-basic-offset: 2 -*-
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 1999-2006 Licq developers
+ * Copyright (C) 1999-2009 Licq developers
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@
 
 #include <QDialog>
 
+#include <licq_types.h>
+
 class QLineEdit;
 
 namespace LicqQtGui
@@ -34,14 +36,13 @@ class AuthUserDlg : public QDialog
    Q_OBJECT
 
 public:
-  AuthUserDlg(QString id, unsigned long ppid, bool grant, QWidget* parent = 0);
+  AuthUserDlg(const UserId& userId, bool grant, QWidget* parent = 0);
 
 private:
   QLineEdit* myUin;
   MLEdit* myResponse;
 
-  QString myId;
-  unsigned long myPpid;
+  UserId myUserId;
   bool myGrant;
 
 private slots:
