@@ -1,7 +1,7 @@
 // -*- c-basic-offset: 2 -*-
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 1999-2006 Licq developers
+ * Copyright (C) 1999-2009 Licq developers
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -104,15 +104,21 @@ static const int col_array[] =
 
 
 // ---------------------------------------------------------------------------
-ChatDlg::ChatDlg(QString id, unsigned long ppid, QWidget* parent)
+ChatDlg::ChatDlg(const UserId& userId, QWidget* parent)
   : QDialog(parent),
-    myId(id),
-    myPpid(ppid),
     myAudio(true)
 {
   Support::setWidgetProps(this, "ChatDialog");
   setAttribute(Qt::WA_DeleteOnClose, true);
 
+  const LicqUser* user = gUserManager.fetchUser(userId);
+  if (user != NULL)
+  {
+    myId = user->accountId().c_str();
+    myPpid = user->ppid();
+    gUserManager.DropUser(user);
+  }
+
   sn = NULL;
 
   m_nMode = CHAT_PANE;
@@ -734,7 +740,7 @@ void ChatDlg::slot_chat()
         QString n = UserCodec::codecForCChatUser(u)->toUnicode(u->Name());
 
         if (n.isEmpty())
-          n = u->Id();
+          n = USERID_TOSTR(u->userId());
         chatClose(u);
         InformUser(this, tr("%1 closed connection.").arg(n));
         break;
@@ -902,7 +908,7 @@ void ChatDlg::slot_chat()
 
       default:
       {
-        gLog.Error("%sInternal Error: invalid command from chat manager (%d).\n",
+        gLog.Warn("%sInternal Error: invalid command from chat manager (%d).\n",
            L_ERRORxSTR, e->Command());
         break;
       }
@@ -1131,7 +1137,7 @@ ChatWindow::ChatWindow (QWidget* parent)
 
 // -----------------------------------------------------------------------------
 
-void ChatWindow::appendNoNewLine(QString s)
+void ChatWindow::appendNoNewLine(const QString& s)
 {
   QTextCursor tc = textCursor();
   tc.movePosition(QTextCursor::End);
