@@ -1,6 +1,6 @@
 /*
  * This file is part of Licq, an instant messaging client for UNIX.
- * Copyright (C) 1999-2006 Licq developers
+ * Copyright (C) 1999-2009 Licq developers
  *
  * Licq is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 class QCheckBox;
 class QPushButton;
 
-class ICQEvent;
+class LicqEvent;
 
 namespace LicqQtGui
 {
@@ -49,7 +49,7 @@ private:
 
 private slots:
   void ok();
-  void doneUserFcn(ICQEvent* e);
+  void doneUserFcn(const LicqEvent* e);
 };
 
 } // namespace LicqQtGui
