@@ -479,8 +479,11 @@ bool UserSendCommon::eventFilter(QObject* watched, QEvent* e)
       const bool isEnter = (key->key() == Qt::Key_Enter || key->key() == Qt::Key_Return);
       if (isEnter)
       {
-        if (key->modifiers() & Qt::ControlModifier)
+        if (key->modifiers() & (Qt::ControlModifier | Qt::ShiftModifier))
+        {
           myMessageEdit->insertPlainText("\n");
+          myMessageEdit->ensureCursorVisible();
+        }
         else
           mySendButton->animateClick();
         return true; // filter the event out
