@@ -6,9 +6,7 @@
  * This program is licensed under the terms found in the LICENSE file.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #ifdef USE_HEBREW
 /*
@@ -48,6 +46,7 @@ char *strhebpatch(char *dest, const char *src)
 	short int mode = 0, imode;
 	const char *hmark = NULL, *lmark, *nmark, *nlmark;
 	char ch;
+  const char* srcstart = src;
 
 	if (src == NULL)
 		return NULL;
@@ -69,7 +68,8 @@ char *strhebpatch(char *dest, const char *src)
 			if (*src == 0  ||  iseng(*src))
 			{
 				lmark = src-1;
-				while ((!isheb(*lmark)) && (!ispunct(*lmark))) lmark--;
+        while (lmark > srcstart && !isheb(*lmark) && !ispunct(*lmark))
+          lmark--;
 				src = lmark;
 				imode = 0;
 				nmark = NULL;
@@ -114,6 +114,8 @@ char *strhebpatch(char *dest, const char *src)
 				hmark = NULL;
 				mode = 0;
 			}
+      if (*src == '\0')
+        *dest = '\0';
 		}
 		if (!*src++)
 			break;
@@ -141,15 +143,16 @@ char* GetArg(char* input, int index)
 	char *temp=NULL, *tmp=NULL;
 	char *arg=NULL, *arg2=NULL;
 	int i=0;
+  char* saveptr = NULL;
 
 	temp = (char*) malloc(strlen(input)+1);
 	tmp = temp;
 
 	strcpy(temp, input);
 
-	arg = strtok(temp, "\n");
+  arg = strtok_r(temp, "\n", &saveptr);
 	for(i = 0; (i < index) && (arg!=NULL); i++)
-		arg = strtok(NULL, "\n");
+    arg = strtok_r(NULL, "\n", &saveptr);
 
 	if(arg != NULL)
 	{
@@ -164,6 +167,7 @@ char* hebrev(char* src)
 {
         char* temp_str = NULL;
 	char* temp = NULL;
+  char* arg = NULL;
         int i=0;
 	int size = 0;
 	if(src == NULL)
@@ -172,21 +176,23 @@ char* hebrev(char* src)
 	if((temp_str = (char*)malloc(strlen(src)+1))== NULL)
 		return NULL;
 
-	temp = GetArg(src, i);
-	while(temp != NULL)
+  arg = GetArg(src, i);
+	while(arg != NULL)
 	{
 		i++;
-		temp = hebrew(temp);
+  temp = hebrew(arg);
+  free(arg);
 		memcpy(temp_str + size , temp, strlen(temp));
 		size += strlen(temp) ;
 		temp_str[size++] = '\n';
 	
 		free(temp);
 		temp = NULL;
-		temp = GetArg(src, i);
+    arg = GetArg(src, i);
 	}
-	free(temp);
-	temp_str[size]= '\0';	
+  // Above loop adds a line break after last line that wasn't there in src
+  //   replace it with the null terminator
+  temp_str[--size]= '\0';
 	return temp_str;
 }
 
