@@ -23,7 +23,6 @@ static const char LICQ_CONF[] =
 "ErrorTypes = 6\n"
 "Rejects = log.rejects\n"
 "Translation = none\n"
-"UrlViewer = viewurl-netscape.sh\n"
 "Terminal = xterm -T Licq -e \n"
 "ProxyEnabled = 0\n"
 "ProxyServerType = 1\n"
@@ -39,15 +38,7 @@ static const char LICQ_CONF[] =
 "Command = play\n"
 "\n"
 "[groups]\n"
-"NumOfGroups = 3\n"
-"DefaultGroup = 0\n"
-"NewUserGroup = 1\n"
-"Group1.name = New Users\n"
-"Group2.name = Friends\n"
-"Group3.name = Family\n"
-"Group1.id = 0\n"
-"Group2.id = 0\n"
-"Group3.id = 0\n"
+"NumOfGroups = 0\n"
 "\n"
 "[owners]\n"
 "NumOfOwners = 0\n"
