@@ -420,7 +420,7 @@ bool INetSocket::connectTo(const string& remoteName, uint16_t remotePort, ProxyS
   struct addrinfo* ai;
   for (ai = addrs; ai != NULL; ai = ai->ai_next)
   {
-    memcpy(&myRemoteAddr, ai->ai_addr, sizeof(myRemoteAddrStorage));
+    memcpy(&myRemoteAddr, ai->ai_addr, ai->ai_addrlen);
 
     // We didn't use getaddrinfo to lookup port so set in manually
     if (myRemoteAddr.sa_family == AF_INET)
@@ -448,7 +448,7 @@ bool INetSocket::connectTo(const string& remoteName, uint16_t remotePort, ProxyS
 #endif
 
     // Try to connect, exit loop if successful
-    if (connect(m_nDescriptor, (struct sockaddr*)&myRemoteAddr, sizeof(myRemoteAddrStorage)) != -1)
+    if (connect(m_nDescriptor, (struct sockaddr*)&myRemoteAddr, ai->ai_addrlen) != -1)
       break;
 
     // Failed to connect, close socket and try next
@@ -489,8 +489,18 @@ bool INetSocket::StartServer(unsigned int _nPort)
   {
     // IPv6 socket created
 
+    // Make sure we can accept connections for IPv4 as well
+    int i = 0;
+    if (setsockopt(m_nDescriptor, IPPROTO_IPV6, IPV6_V6ONLY, &i, sizeof(i)) < 0)
+    {
+      m_nErrorType = SOCK_ERROR_errno;
+      ::close(m_nDescriptor);
+      m_nDescriptor = -1;
+      return false;
+    }
+
 #ifdef IPV6_PORTRANGE
-    int i = IPV6_PORTRANGE_HIGH;
+    i = IPV6_PORTRANGE_HIGH;
     if (setsockopt(m_nDescriptor, IPPROTO_IPV6, IPV6_PORTRANGE, &i, sizeof(i)) < 0)
     {
       m_nErrorType = SOCK_ERROR_errno;
